Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(749)

Unified Diff: src/x64/macro-assembler-x64.h

Issue 197873029: Tweaked FlooringDiv back to TruncatingDiv again. (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Rebased Created 6 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/x64/lithium-codegen-x64.cc ('k') | src/x64/macro-assembler-x64.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/x64/macro-assembler-x64.h
diff --git a/src/x64/macro-assembler-x64.h b/src/x64/macro-assembler-x64.h
index 90d9f52850eb5b0c35dc41982dae02736c593f9f..d5a028c8409d088c260783ff50bd022d3829a11e 100644
--- a/src/x64/macro-assembler-x64.h
+++ b/src/x64/macro-assembler-x64.h
@@ -1367,9 +1367,9 @@ class MacroAssembler: public Assembler {
Register filler);
// Emit code for a flooring division by a constant. The dividend register is
// unchanged, the result is in rdx, and rax gets clobbered.
- void FlooringDiv(Register dividend, int32_t divisor);
+ void TruncatingDiv(Register dividend, int32_t divisor);
// ---------------------------------------------------------------------------
// StatsCounter support
« no previous file with comments | « src/x64/lithium-codegen-x64.cc ('k') | src/x64/macro-assembler-x64.cc » ('j') | no next file with comments »
@@ -1367,9 +1367,9 @@ class MacroAssembler: public Assembler {
Register filler);
- // Emit code for a flooring division by a constant. The dividend register is
+ // Emit code for a truncating division by a constant. The dividend register is
// unchanged, the result is in rdx, and rax gets clobbered.

Powered by Google App Engine
This is Rietveld 408576698